import os
import ufh.ufhUtils as utils

class redactor():

    def __init__(self, path):
        self.path = path


    def lineIndexer(self, index, lines, firstWord):
        array = utils.fileReader(self.path)
        for  i in range(len(array)):
            line = array[i]
            if (line.find('_') == len(firstWord)):
                j = 0
                number = ''
                while line[(len(firstWord)+1)+j].isdigit():
                    number += line[(len(firstWord)+1)+j]
                    j+=1

                lineReplaced = line.replace(f'_{number}_', f'_{int(i/lines)+index}_')
                array[i] = lineReplaced

        utils.fileWriter(array, self.path)
        print('\033[36m'+'INDEXES WAS UPDATED'+'\033[37m')


    def indexIncrice(self, relativeWord, n=1):
        array = utils.fileReader(self.path)
        for  i in range(len(array)):
            line = array[i]
            if (line.find(f'{relativeWord}_')) == -1: continue
            number = ''
            j = 0

            indexPos = len(relativeWord) + line.find(relativeWord) + 1

            while line[indexPos+j].isdigit():
                number += line[indexPos+j]
                j+=1

            lineReplaced = line.replace(f'{relativeWord}_{number}', f'{relativeWord}_{int(int(number)+n)}')
            array[i] = lineReplaced


        utils.fileWriter(array, self.path)
        print(f'\033[36mINDEXES AFTER \033[33m{relativeWord}_n \033[36mWAS UPDATED \033[1;32mOK\033[0;37m')


    def renamer(self, nameOld, nameNew):
        array = utils.utils().fileReader(self.path)
        for i in range(len(array)):
            line = array[i]

            if ((nameNew in line) != True):
                lineReplaced = line.replace(nameOld, nameNew)
                array[i] = lineReplaced
            elif ((nameNew in nameOld) == True):
                lineReplaced = line.replace(nameOld, nameNew)
                array[i] = lineReplaced

        utils.fileWriter(array, self.path)
        print('\033[36m'+f'NAMES WAS UPDATED ON [{nameNew}]'+'\033[37m')


    def pricer(self, relativeWord, multiple=0.5, newNumber=0, maxPrice=False):
        array = utils.utils().fileReader(self.path)
        for i in range(len(array)):
            line = array[i]
            if (line.find(f'{relativeWord}') != -1):
                j = 0
                number = ''
                while (line.find(f'{relativeWord}')+len(relativeWord)+1+j) < len(line):
                    number += line[line.find(f'{relativeWord}')+len(relativeWord)+1+j]
                    j+=1

                if newNumber:
                    lineReplaced = line.replace(f'{number}', f'{newNumber}')
                    array[i] = lineReplaced
                else:
                    if maxPrice:
                        newNum = int(int(number)*multiple)
                        if newNum > maxPrice: newNum = maxPrice
                        lineReplaced = line.replace(f'{number}', f'{newNum}')
                        array[i] = lineReplaced
                    else:
                        lineReplaced = line.replace(f'{number}', f'{int(int(number)*multiple)}')
                        array[i] = lineReplaced

        utils.fileWriter(array, self.path)
        print('\033[36m'+'PRICES WAS UPDATED'+'\033[37m')


from setuptools import setup, find_packages

with open("README.md", "r") as readme_file:
    readme = readme_file.read()

setup(
    name="ufh",
    version="1.0.1",
    author="Cobalt-A",
    author_email="nikitos.eng@gmail.com",
    description="A package to redact unturned dat files",
    long_description=readme,
    long_description_content_type="text/markdown",
    url="https://github.com/UntFileHelper/UFH.git",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3.10",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
    ],
)


import os

def fileReader(path):
    array = []
    with open(path) as file:
        array = [row.strip() for row in file]
    return array

def fileWriter(array, path):
    with open(path, 'w') as file:
        for  i in range(len(array)):
            line = array[i]
            file.write(line + '\n')

def datFiles(path):
    files = []
    n = 0
    for filename in os.listdir(path):
        if (os.path.isdir(f'{path}/{filename}')):
            datFiles(f'{path}/{filename}')
        else:
            if (filename.find('.dat') != -1):
                files.insert(n, f'{path}/{filename}')
                n+=1
    return files

def guidDeleter(path):
    for filename in datFiles(path):
        print(filename)
        array = fileReader(f'{filename}')
        if (array[0].find('GUID') != -1):
            array.remove(array[0])

            fileWriter(array, f'{filename}')
            print(f'GUID deleted in {filename}')